@@ -4,5 +4,5 @@ set -eux
 SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
 
 
-cargo install --debug --path "$SCRIPT_DIR/.."
+cargo install --debug --locked --path "$SCRIPT_DIR/.."
 cargo profile $@
\ No newline at end of file
